<?php

namespace Drupal\simple_theme_switch\Theme;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Theme\ThemeNegotiatorInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Theme Negotiator class.
 */
class SimpleThemeSwitchThemeNegotiator implements ThemeNegotiatorInterface {

  /**
   * Constructs a Theme Negotiator class object.
   */
  public function __construct(
    private ConfigFactoryInterface $configFactory,
    private ModuleHandlerInterface $moduleHandler,
    private RequestStack $requestStack,
  ) {}

  /**
   * {@inheritDoc}
   */
  public function applies(RouteMatchInterface $route_match) {
    $apply = FALSE;

    // If the conditions in the hook are matched, the admin theme will be
    // applied.
    $hook = 'simple_theme_switch_flag_for_applies_of_admin_theme';
    $args = [$route_match, $this->requestStack->getCurrentRequest()];
    if (\array_filter($this->moduleHandler->invokeAll($hook, $args))) {
      $apply = TRUE;
    }

    // If not, apply the admin theme to the user login form, the user password
    // reminder form and the user password reset confirmation form.
    elseif ($current_route_name = $route_match->getRouteName()) {
      foreach ([
        'user.login',
        'user.pass',
        'user.reset.form',
      ] as $pattern) {
        if ($pattern === $current_route_name) {
          $apply = TRUE;
          break;
        }
      }
    }

    return $apply;
  }

  /**
   * {@inheritDoc}
   */
  public function determineActiveTheme(RouteMatchInterface $route_match) {
    return $this->configFactory->get('system.theme')->get('admin');
  }

}
